@@ -511,8 +511,8 @@ class URLopener:
         if user: user, passwd = splitpasswd(user)
         else: passwd = None
         host = unquote(host)
-        user = unquote(user or '')
-        passwd = unquote(passwd or '')
+        user = user or ''
+        passwd = passwd or ''
         host = socket.gethostbyname(host)
         if not port:
             import ftplib
@@ -1064,7 +1064,12 @@ def splithost(url):
         _hostprog = re.compile('^//([^/?]*)(.*)$')
 
     match = _hostprog.match(url)
-    if match: return match.group(1, 2)
+    if match:
+        host_port = match.group(1)
+        path = match.group(2)
+        if path and not path.startswith('/'):
+            path = '/' + path
+        return host_port, path
     return None, url
 
 _userprog = None
@@ -1076,7 +1081,7 @@ def splituser(host):
         _userprog = re.compile('^(.*)@(.*)$')
 
     match = _userprog.match(host)
-    if match: return map(unquote, match.group(1, 2))
+    if match: return match.group(1, 2)
     return None, host
 
 _passwdprog = None
@@ -1228,6 +1233,8 @@ def quote(s, safe='/'):
     """
     # fastpath
     if not s:
+        if s is None:
+            raise TypeError('None object cannot be quoted')
         return s
     cachekey = (safe, always_safe)
     try:
@@ -1343,6 +1350,7 @@ def proxy_bypass_environment(host):
     hostonly, port = splitport(host)
     # check if the host ends with any of the DNS suffixes
     for name in no_proxy.split(','):
+        name = name.strip()
         if name and (hostonly.endswith(name) or host.endswith(name)):
             return 1
     # otherwise, don't bypass
@@ -1401,7 +1409,7 @@ if sys.platform == 'darwin':
 
                 else:
                     mask = int(mask[1:])
-                    mask = 32 - mask
+                mask = 32 - mask
 
                 if (hostIP >> mask) == (base >> mask):
                     return True
@@ -1465,6 +1473,7 @@ elif os.name == 'nt':
                         proxies['http'] = proxyServer
                     else:
                         proxies['http'] = 'http://%s' % proxyServer
+                        proxies['https'] = 'https://%s' % proxyServer
                         proxies['ftp'] = 'ftp://%s' % proxyServer
             internetSettings.Close()
         except (WindowsError, ValueError, TypeError):
